==> MIRit_0.99.10.tar.gz: MIRit/inst/doc/MIRit.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----getPackage, eval=FALSE---------------------------------------------------
#  ## install MIRit from Bioconductor
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("MIRit")

## ----getPackageDevel, eval=FALSE----------------------------------------------
#  ## install the development version from GitHub
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("jacopo-ronchi/MIRit")

## ----loadPackage, message=FALSE-----------------------------------------------
## load MIRit
library(MIRit)

## ----example------------------------------------------------------------------
## load count matrix for genes
data(geneCounts, package = "MIRit")

## load count matrix for miRNAs
data(mirnaCounts, package = "MIRit")

## ----geneExpr, echo=FALSE-----------------------------------------------------
## print a table for gene expression matrix
knitr::kable(geneCounts[seq(5), seq(5)], digits = 2, caption = "Gene expression matrix. An expression matrix containing normalized values, with row names according to hgnc.")

## ----mirnaExpr, echo=FALSE----------------------------------------------------
## print a table for miRNA expression matrix
knitr::kable(mirnaCounts[seq(5), seq(5)], digits = 2, caption = "MiRNA expression matrix. An expression matrix containing normalized values, with row names according to miRBase.")

## ----colnames-----------------------------------------------------------------
## print sample names in geneCounts
colnames(geneCounts)

## print sample names in mirnaCounts
colnames(mirnaCounts)

## check if samples in geneCounts are equal to those in mirnaCounts
identical(colnames(geneCounts), colnames(mirnaCounts))

## ----metadata-----------------------------------------------------------------
## create a data.frame containing sample metadata
meta <- data.frame(
    primary = colnames(mirnaCounts),
    mirnaCol = colnames(mirnaCounts),
    geneCol = colnames(geneCounts),
    disease = c(rep("PTC", 8), rep("NTH", 8)),
    patient = c(rep(paste("Sample_", seq(8), sep = ""), 2))
)

## ----mirnaObj-----------------------------------------------------------------
## create the MirnaExperiment object
experiment <- MirnaExperiment(
    mirnaExpr = mirnaCounts,
    geneExpr = geneCounts,
    samplesMetadata = meta,
    pairedSamples = TRUE
)

## ----mds, fig.wide=TRUE, fig.cap="MDS plots for miRNAs and genes. Both plots show that the main source of variability is given by the disease condition."----
geneMDS <- plotDimensions(experiment,
    assay = "genes",
    condition = "disease",
    title = "MDS plot for genes"
)
mirnaMDS <- plotDimensions(experiment,
    assay = "microRNA",
    condition = "disease",
    title = "MDS plot for miRNAs"
)

ggpubr::ggarrange(geneMDS, mirnaMDS,
    nrow = 1, labels = "AUTO",
    common.legend = TRUE
)

## ----model--------------------------------------------------------------------
## design the linear model for both genes and miRNAs
model <- ~ disease + patient

## ----diffexp------------------------------------------------------------------
## perform differential expression for genes
experiment <- performGeneDE(experiment, group = "disease", contrast = "PTC-NTH", design = model)

## perform differential expression for miRNAs
experiment <- performMirnaDE(experiment, group = "disease", contrast = "PTC-NTH", design = model)

## ----accessDe-----------------------------------------------------------------
## access DE results for genes
deGenes <- geneDE(experiment)

## access DE results for miRNAs
deMirnas <- mirnaDE(experiment)

## ----volcano, fig.wide=TRUE, fig.cap="Volcano plots of gene and miRNA differential expression."----
## create a volcano plot for genes
geneVolcano <- plotVolcano(experiment,
    assay = "genes",
    title = "Gene differential expression"
)

## create a volcano plot for miRNAs
mirnaVolcano <- plotVolcano(experiment,
    assay = "microRNA",
    title = "miRNA differential expression"
)

## plot graphs side by side
ggpubr::ggarrange(geneVolcano, mirnaVolcano,
    nrow = 1, labels = "AUTO",
    common.legend = TRUE
)

## ----thyroidBars, fig.wide=FALSE, fig.cap="Differential expression bar plots for different thyroid genes. Differential expression analysis demonstrated how TG, TPO, DIO2 and PAX8 result downregulated in thyroid cancer."----
## create a bar plot for all thyroid features
thyrBar <- plotDE(experiment,
    features = c("TG", "TPO", "DIO2", "PAX8"),
    graph = "barplot", linear = FALSE
)

## show the resulting plot
thyrBar

## ----species------------------------------------------------------------------
## list available species for Reactome database
supportedOrganisms("Reactome")

## ----ora----------------------------------------------------------------------
## perform over-representation analysis with GO
ora <- enrichGenes(experiment, method = "ORA", database = "GO", organism = "Homo sapiens")

## ----gsea---------------------------------------------------------------------
## perform gene-set enrichment analysis with KEGG
gse <- enrichGenes(experiment, method = "GSEA", database = "KEGG", organism = "Homo sapiens")

## ----gseaTab, echo=FALSE------------------------------------------------------
## display the results of GSEA
knitr::kable(enrichmentResults(gse), digits = 2, caption = "GSEA results. A table listing the affected KEGG pathways in thyroid cancer.")

## ----oraDot, fig.wide=FALSE, fig.cap="ORA results for downregulated genes. The enrichment of downregulated genes through the gene sets provided by GO database."----
## create a dot plot for ORA
enrichmentDotplot(ora$downregulated, title = "Depleted functions")

## ----gsePlot, fig.wide=FALSE, fig.cap="GSEA-style plot for Thyroid hormone synthesis. This type of plot shows the running sum that GSEA uses to determinate the enrichment score for each pathway."----
## create a GSEA plot
gseaPlot(gse, "Thyroid hormone synthesis", rankingMetric = TRUE)

## ----seach_disease, eval=FALSE------------------------------------------------
#  ## identify the EFO ID corresponding to Alzheimer's disease
#  searchDisease("alzheimer")

## ----snp_association, eval=FALSE----------------------------------------------
#  ## detect disease-SNPs occuring at DE-miRNAs loci
#  association <- findMirnaSNPs(experiment, "Alzheimer disease")

## ----track_plot, eval=FALSE---------------------------------------------------
#  ## create a track plot to represent disease-SNPs at DE-miRNA loci
#  mirVariantPlot("rs2632516", association, showContext = TRUE)

## ----targets, eval=FALSE------------------------------------------------------
#  ## retrieve miRNA target genes
#  experiment <- getTargets(experiment)

## ----echo=FALSE---------------------------------------------------------------
## load the example object
experiment <- loadExamples()

## ----correlation--------------------------------------------------------------
## perform a correlation analysis
experiment <- mirnaIntegration(experiment, test = "correlation")

## ----correlationResults-------------------------------------------------------
## extract correlation results
integrationResults <- integration(experiment)

## take a look at correlation results
head(integrationResults)

## ----corPlot, fig.wide=TRUE, fig.cap="Correlation between miRNAs and key thyroid genes. These plots suggest that the upregulation of miR-146b-5p and miR-146b-3p may be responsible for the downregulation of DIO2 and PAX8, respectively."----
## plot the correlation between miR-146b-5p and DIO2
cor1 <- plotCorrelation(experiment,
    mirna = "hsa-miR-146b-5p",
    gene = "DIO2", condition = "disease"
)

## plot the correlation between miR-146b-3p and PAX8
cor2 <- plotCorrelation(experiment,
    mirna = "hsa-miR-146b-3p",
    gene = "PAX8", condition = "disease"
)

## plot graphs side by side
ggpubr::ggarrange(cor1, cor2,
    nrow = 1, labels = "AUTO",
    common.legend = TRUE
)

## ----association, eval=FALSE--------------------------------------------------
#  ## perform a one-sided inverse association
#  exp.association <- mirnaIntegration(experiment,
#      test = "association",
#      associationMethod = "boschloo",
#      pAdjustment = "none"
#  )

## ----fry, eval=FALSE----------------------------------------------------------
#  ## perform the integrative analysis through 'fry' method
#  exp.fry <- mirnaIntegration(experiment,
#      test = "fry",
#      pCutoff = 0.1
#  )

## ----intTargEnr, fig.cap="Functional enrichment of integrated targets. This dot plot shows the enriched diseases for downregulated genes."----
## enrichment of integrated targets
oraTarg <- enrichTargets(experiment, database = "DO")

## show a dot plot for the enrichment of downregulated genes
enrichmentDotplot(oraTarg$downregulated,
    showTerms = 7,
    showTermsParam = "padj", title = "Depleted diseases"
)

## ----augmented_networks, eval=FALSE-------------------------------------------
#  ## create miRNA-augmented networks using KEGG pathways
#  networks <- preparePathways(experiment,
#      database = "KEGG",
#      organism = "Homo sapiens"
#  )

## ----taipa, eval=FALSE--------------------------------------------------------
#  ## set seed for reproducible results
#  set.seed(1234)
#  
#  ## perform TAIPA
#  taipa <- topologicalAnalysis(experiment,
#      pathways = networks,
#      nPerm = 10000
#  )

## ----echo=FALSE---------------------------------------------------------------
## perform TAIPA
taipa <- loadExamples("IntegrativePathwayAnalysis")

## ----integratedPathways-------------------------------------------------------
## extract the results of TAIPA
perturbedNetworks <- integratedPathways(taipa)

## ----integrationDot, fig.wide=FALSE, fig.cap="The perturbation of miRNA-mRNA networks in thyroid cancer. This dot plot display the impairment of the biological processes involved in the production of thyroid hormone, further highlighting the disruption of this mechanism in this disease."----
## produce a dotplot that shows the most affected networks
intDot <- integrationDotplot(taipa)
intDot

## ----thyroidNetwork, fig.wide=TRUE, fig.cap="Impaired miRNA-mRNA regulatory network prevents thyroid hormone synthesis in thyroid cancer. The network created by MIRit suggests that the upregulation of miR-146b-5p and miR-146b-3p may be responsible for diminished expression of PAX8, which in turn causes reduced transcription of thyroid hormone."----
## plot the impaired network responsible for reduced TG synthesis
visualizeNetwork(taipa, "Thyroid hormone synthesis")

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()

==> MIRit_0.99.11.tar.gz: MIRit/inst/doc/MIRit.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----getPackage, eval=FALSE---------------------------------------------------
#  ## install MIRit from Bioconductor
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("MIRit")

## ----getPackageDevel, eval=FALSE----------------------------------------------
#  ## install the development version from GitHub
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("jacopo-ronchi/MIRit")

## ----loadPackage, message=FALSE-----------------------------------------------
## load MIRit
library(MIRit)

## ----example------------------------------------------------------------------
## load count matrix for genes
data(geneCounts, package = "MIRit")

## load count matrix for miRNAs
data(mirnaCounts, package = "MIRit")

## ----geneExpr, echo=FALSE-----------------------------------------------------
## print a table for gene expression matrix
knitr::kable(geneCounts[seq(5), seq(5)], digits = 2, caption = "Gene expression matrix. An expression matrix containing normalized values, with row names according to hgnc.")

## ----mirnaExpr, echo=FALSE----------------------------------------------------
## print a table for miRNA expression matrix
knitr::kable(mirnaCounts[seq(5), seq(5)], digits = 2, caption = "MiRNA expression matrix. An expression matrix containing normalized values, with row names according to miRBase.")

## ----colnames-----------------------------------------------------------------
## print sample names in geneCounts
colnames(geneCounts)

## print sample names in mirnaCounts
colnames(mirnaCounts)

## check if samples in geneCounts are equal to those in mirnaCounts
identical(colnames(geneCounts), colnames(mirnaCounts))

## ----metadata-----------------------------------------------------------------
## create a data.frame containing sample metadata
meta <- data.frame(primary = colnames(mirnaCounts),
                   mirnaCol = colnames(mirnaCounts),
                   geneCol = colnames(geneCounts),
                   disease = c(rep("PTC", 8), rep("NTH", 8)),
                   patient = c(rep(paste("Sample_", seq(8), sep = ""), 2)))

## ----mirnaObj-----------------------------------------------------------------
## create the MirnaExperiment object
experiment <- MirnaExperiment(mirnaExpr = mirnaCounts,
                              geneExpr = geneCounts,
                              samplesMetadata = meta,
                              pairedSamples = TRUE)

## ----mds, fig.wide=TRUE, fig.cap="MDS plots for miRNAs and genes. Both plots show that the main source of variability is given by the disease condition."----
geneMDS <- plotDimensions(experiment,
                          assay = "genes",
                          condition = "disease",
                          title = "MDS plot for genes")

mirnaMDS <- plotDimensions(experiment,
                           assay = "microRNA",
                           condition = "disease",
                           title = "MDS plot for miRNAs")

ggpubr::ggarrange(geneMDS, mirnaMDS,
                  nrow = 1, labels = "AUTO", common.legend = TRUE)

## ----model--------------------------------------------------------------------
## design the linear model for both genes and miRNAs
model <- ~ disease + patient

## ----diffexp, eval=FALSE------------------------------------------------------
#  ## perform differential expression for genes
#  experiment <- performGeneDE(experiment,
#                              group = "disease",
#                              contrast = "PTC-NTH",
#                              design = model)
#  
#  ## perform differential expression for miRNAs
#  experiment <- performMirnaDE(experiment,
#                               group = "disease",
#                               contrast = "PTC-NTH",
#                               design = model)

## ----echo=FALSE---------------------------------------------------------------
## load the example object
experiment <- loadExamples()

## ----accessDe-----------------------------------------------------------------
## access DE results for genes
deGenes <- geneDE(experiment)

## access DE results for miRNAs
deMirnas <- mirnaDE(experiment)

## ----volcano, fig.wide=TRUE, fig.cap="Volcano plots of gene and miRNA differential expression."----
## create a volcano plot for genes
geneVolcano <- plotVolcano(experiment,
                           assay = "genes",
                           title = "Gene differential expression")

## create a volcano plot for miRNAs
mirnaVolcano <- plotVolcano(experiment,
                            assay = "microRNA",
                            title = "miRNA differential expression")

## plot graphs side by side
ggpubr::ggarrange(geneVolcano, mirnaVolcano,
                  nrow = 1, labels = "AUTO", common.legend = TRUE)

## ----thyroidBars, fig.wide=FALSE, fig.cap="Differential expression bar plots for different thyroid genes. Differential expression analysis demonstrated how TG, TPO, DIO2 and PAX8 result downregulated in thyroid cancer."----
## create a bar plot for all thyroid features
thyrBar <- plotDE(experiment,
                  features = c("TG", "TPO", "DIO2", "PAX8"),
                  graph = "barplot", linear = FALSE)

## show the resulting plot
thyrBar

## ----species------------------------------------------------------------------
## list available species for Reactome database
supportedOrganisms("Reactome")

## ----ora----------------------------------------------------------------------
## perform over-representation analysis with GO
ora <- enrichGenes(experiment,
                   method = "ORA",
                   database = "GO",
                   organism = "Homo sapiens")

## ----gsea---------------------------------------------------------------------
## set seed for reproducible results
set.seed(1234)

## perform gene-set enrichment analysis with KEGG
gse <- enrichGenes(experiment,
                   method = "GSEA",
                   database = "KEGG",
                   organism = "Homo sapiens")

## ----gseaTab, echo=FALSE------------------------------------------------------
## display the results of GSEA
knitr::kable(enrichmentResults(gse), digits = 2, caption = "GSEA results. A table listing the affected KEGG pathways in thyroid cancer.")

## ----oraDot, fig.wide=FALSE, fig.cap="ORA results for downregulated genes. The enrichment of downregulated genes through the gene sets provided by GO database."----
## create a dot plot for ORA
enrichmentDotplot(ora$downregulated, title = "Depleted functions")

## ----gsePlot, fig.wide=FALSE, fig.cap="GSEA-style plot for Thyroid hormone synthesis. This type of plot shows the running sum that GSEA uses to determinate the enrichment score for each pathway."----
## create a GSEA plot
gseaPlot(gse, "Thyroid hormone synthesis", rankingMetric = TRUE)

## ----seach_disease, eval=FALSE------------------------------------------------
#  ## identify the EFO ID corresponding to Alzheimer's disease
#  searchDisease("alzheimer")

## ----snp_association, eval=FALSE----------------------------------------------
#  ## detect disease-SNPs occuring at DE-miRNAs loci
#  association <- findMirnaSNPs(experiment, "Alzheimer disease")

## ----track_plot, eval=FALSE---------------------------------------------------
#  ## create a track plot to represent disease-SNPs at DE-miRNA loci
#  mirVariantPlot("rs2632516", association, showContext = TRUE)

## ----targets, eval=FALSE------------------------------------------------------
#  ## retrieve miRNA target genes
#  experiment <- getTargets(experiment)

## ----correlation--------------------------------------------------------------
## perform a correlation analysis
experiment <- mirnaIntegration(experiment, test = "correlation")

## ----correlationResults-------------------------------------------------------
## extract correlation results
integrationResults <- integration(experiment)

## take a look at correlation results
head(integrationResults)

## ----corPlot, fig.wide=TRUE, fig.cap="Correlation between miRNAs and key thyroid genes. These plots suggest that the upregulation of miR-146b-5p and miR-146b-3p may be responsible for the downregulation of DIO2 and PAX8, respectively."----
## plot the correlation between miR-146b-5p and DIO2
cor1 <- plotCorrelation(experiment,
                        mirna = "hsa-miR-146b-5p",
                        gene = "DIO2",
                        condition = "disease")

## plot the correlation between miR-146b-3p and PAX8
cor2 <- plotCorrelation(experiment,
                        mirna = "hsa-miR-146b-3p",
                        gene = "PAX8",
                        condition = "disease")

## plot graphs side by side
ggpubr::ggarrange(cor1, cor2, nrow = 1,
                  labels = "AUTO", common.legend = TRUE)

## ----association, eval=FALSE--------------------------------------------------
#  ## perform a one-sided inverse association
#  exp.association <- mirnaIntegration(experiment,
#                                      test = "association",
#                                      associationMethod = "boschloo",
#                                      pAdjustment = "none")

## ----fry, eval=FALSE----------------------------------------------------------
#  ## perform the integrative analysis through 'fry' method
#  exp.fry <- mirnaIntegration(experiment,
#                              test = "fry",
#                              pCutoff = 0.1)

## ----intTargEnr, fig.cap="Functional enrichment of integrated targets. This dot plot shows the enriched diseases for downregulated genes."----
## enrichment of integrated targets
oraTarg <- enrichTargets(experiment, database = "DO")

## show a dot plot for the enrichment of downregulated genes
enrichmentDotplot(oraTarg$downregulated,
                  showTerms = 7,
                  showTermsParam = "padj",
                  title = "Depleted diseases")

## ----augmented_networks, eval=FALSE-------------------------------------------
#  ## create miRNA-augmented networks using KEGG pathways
#  networks <- preparePathways(experiment,
#                              database = "KEGG",
#                              organism = "Homo sapiens")

## ----taipa, eval=FALSE--------------------------------------------------------
#  ## set seed for reproducible results
#  set.seed(1234)
#  
#  ## perform TAIPA
#  taipa <- topologicalAnalysis(experiment,
#                               pathways = networks,
#                               nPerm = 10000)

## ----echo=FALSE---------------------------------------------------------------
## perform TAIPA
taipa <- loadExamples("IntegrativePathwayAnalysis")

## ----integratedPathways-------------------------------------------------------
## extract the results of TAIPA
perturbedNetworks <- integratedPathways(taipa)

## ----integrationDot, fig.wide=FALSE, fig.cap="The perturbation of miRNA-mRNA networks in thyroid cancer. This dot plot display the impairment of the biological processes involved in the production of thyroid hormone, further highlighting the disruption of this mechanism in this disease."----
## produce a dotplot that shows the most affected networks
intDot <- integrationDotplot(taipa)
intDot

## ----thyroidNetwork, fig.wide=TRUE, fig.cap="Impaired miRNA-mRNA regulatory network prevents thyroid hormone synthesis in thyroid cancer. The network created by MIRit suggests that the upregulation of miR-146b-5p and miR-146b-3p may be responsible for diminished expression of PAX8, which in turn causes reduced transcription of thyroid hormone."----
## plot the impaired network responsible for reduced TG synthesis
visualizeNetwork(taipa, "Thyroid hormone synthesis")

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()
